@@ -1,22 +1,22 @@
 mmstat            <- new.env(parent=emptyenv())
 mmstat$data       <- list()
 mmstat$lang       <- list()
+mmstat$repository <- list()
 mmstat$version    <- '22.2'
 #
-repolist <- paste0(rappdirs::user_data_dir('mmstat4'), '/repositories')
-if (file.exists(repolist)) {
-  mmstat$repository <- readRDS(repolist)
-} else {
+repolist <- paste0(rappdirs::user_data_dir('mmstat4'), '/repositories.rds')
+if (file.exists(repolist)) mmstat$repository <- readRDS(repolist)
+if (length(mmstat$repository)==0) {
   mmstat$repository <- list(
-    dummy=list(url="https://github.com/sigbertklinke/mmstat4.dummy/archive/refs/heads/main.zip",
-               dir=''),
     hu.data=list(url="https://github.com/sigbertklinke/mmstat4.data/archive/refs/heads/main.zip",
-                 dir=''),
+                 dir=tempdir()),
     hu.stat=list(url="https://github.com/sigbertklinke/mmstat4.stat/archive/refs/heads/main.zip",
-                 dir='')
+                 dir=tempdir()),
+    dummy=list(url="https://github.com/sigbertklinke/mmstat4.dummy/archive/refs/heads/main.zip",
+               dir=tempdir())
     )
 }
-mmstat$repo <- NULL
+mmstat$repo <- names(mmstat$repository)[1]
 
 .onLoad <- function(libname, pkgname) {
   # colors
